@@ -22,9 +22,16 @@ public:
   ~TextSet();
   /* Can't use display lists */
   void render(RenderContext* renderContext);
-  void draw(RenderContext* renderContext);
   virtual void getShapeName(char* buffer, int buflen) { strncpy(buffer, "text", buflen); };
 
+  int getElementCount(void){ return textArray.size(); }
+  
+  Vertex getElementCenter(int index) { return vertexArray[index]; }
+
+  void drawBegin(RenderContext* renderContext);
+  void drawElement(RenderContext* renderContext, int index);
+  void drawEnd(RenderContext* renderContext);
+
 private:
 
   VertexArray vertexArray;
